<?php
/*
Plugin Name: Simple Update Notification
Plugin URI: https://WPupdateNotification.de/
Description: Email notification when updates are available
Version: 1.0
Author: Wirths Media
Author URI: https://wirths-media.de/wordpress-plugins/
License: GPLv3 or later
Text Domain: WPupdateNotification.de

Copyright (C) 2022 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

defined( 'ABSPATH' ) or die();

$WPuN = new WPupdateNotification();

class WPupdateNotification {
	public function __construct() {
        register_activation_hook(__FILE__, [$this, 'WPuN_updateActivate']);
        register_deactivation_hook(__FILE__, [$this, 'WPuN_updateDeactivate']);

        add_action('admin_menu', [$this, 'WPuN_menu']);
        add_action('admin_init', [$this, 'WPuN_settingFields']);
        add_action('WPuN_updateNotifcation', [$this, 'WPuN_status']);

        add_option('WPuN_mailadress', get_option('admin_email'));
        // add_option('WPuN_timestamp', '12:00');
    }

    public function WPuN_menu() {
        add_menu_page(
            'Wordpress Update Notification',
            'Update Notification',
            'manage_options',
            'WPupdateNotification',
            [$this, 'WPuN_page']
        );
    }

    public function WPuN_settingFields() {
        register_setting('WPuN_fields', 'WPuN_mailadress');
        // register_setting('WPuN_fields', 'WPuN_timestamp');
    }

    public function WPuN_updateActivate() {
		if(!wp_next_scheduled('WPuN_updateNotifcation')) {
            // wp_schedule_event(get_option('WPuN_timestamp'), 'daily', 'WPuN_updateNotifcation');
            wp_schedule_event(time(), 'daily', 'WPuN_updateNotifcation');
		}
    }

    public function WPuN_updateDeactivate() {
		if(wp_next_scheduled('WPuN_updateNotifcation')) {
            delete_option('WPuN_mailadress');
            // delete_option('WPuN_timestamp');

            wp_clear_scheduled_hook('WPuN_updateNotifcation');
		}
    }

    public function WPuN_status() {
        $checkUpdates = wp_get_update_data();

        if($checkUpdates['counts'] > 0) {
            $WPuN_mailadress = get_option('WPuN_mailadress');
            $WPuN_blogName   = get_option('blogname');

            if($WPuN_mailadress) {
                wp_mail(
                    $WPuN_mailadress,
                    _e('Update Notification ') . $WPuN_blogName,
                    _e('For your blog ') . '"' . $WPuN_blogName . '"' . _e(' are') . $checkUpdates['counts']['total'] . _e(' updates available') . '.<br>
                    ' . $checkUpdates['counts']['plugins'] . _e(' Plugin Updates') . '<br>
                    ' . $checkUpdates['counts']['themes'] . _e(' Theme Updates') . '<br>
                    ' . $checkUpdates['counts']['wordpress'] . _e(' WordPress Core Updates') . '<br>
                    ' . $checkUpdates['counts']['translations'] . _e(' Translation Updates'),
                    'Content-Type: text/html; charset=UTF-8'
                );
            }
        }
    }

    public function WPuN_page() {
        if(!current_user_can('manage_options')) {
            return;
        }

        $WPuN_mailadress = get_option('WPuN_mailadress') ? get_option('WPuN_mailadress') : get_option('admin_email');
        // $WPuN_timestamp = get_option('WPuN_timestamp') ? get_option('WPuN_timestamp') : '12:00';
        ?>

        <div class="wrap">
            <h1><?php echo _e(get_admin_page_title()); ?></h1>

            <?php settings_errors(); ?>

            <h2><?php echo _e('Settings'); ?></h2>

            <form action="options.php" method="POST">
                <?php settings_fields('WPuN_fields'); ?>

                <table class="form-table">
                    <tr>
                        <th><label for="WPuN_mailadress"><?php echo _e('E-Mail-Adress'); ?></label></th>
                        <td><input type="email" class="regular-text" id="WPuN_mailadress" name="WPuN_mailadress" value="<?php echo esc_html($WPuN_mailadress); ?>" /></td>
                    </tr>
                    <!--<tr>
                        <th><label for="WPuN_timestamp"><?php echo _e('Time'); ?></label></th>
                        <td><input type="time" class="regular-text" id="WPuN_timestamp" name="WPuN_timestamp" value="<?php echo esc_html($WPuN_timestamp); ?>" /></td>
                    </tr>-->
                </table>

                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }


}